pub struct SocketRequest<E, VER: StaticVersionType> { /* private fields */ }

Implementations

source

impl<E: Error, VER: StaticVersionType> SocketRequest<E, VER>

source

pub fn header( self, key: impl Into<HeaderName>, values: impl ToHeaderValues ) -> Self

Set a header on the request.

source

pub async fn connect<FromServer: DeserializeOwned, ToServer: Serialize + ?Sized>( self ) -> Result<Connection<FromServer, ToServer, E, VER>, E>

Start the WebSocket handshake and initiate a connection to the server.

source

pub async fn subscribe<FromServer: DeserializeOwned>( self ) -> Result<Connection<FromServer, Unsupported, E, VER>, E>

Initiate a unidirectional connection to the server.

This is equivalent to self.connect() with the ToServer message type replaced by Unsupported, so that you don’t have to specify the type parameter if it isn’t used.