Crate surf_disco
source ·Expand description
Surf Disco: a client library for Tide Disco applications.
Quick Start
let url = "http://localhost:50000".parse().unwrap();
let client: Client<ClientError, StaticVersion<0,1>> = Client::new(url);
let res: String = client.get("/app/route").send().await.unwrap();Re-exports
pub use client::Client;pub use client::ContentType;pub use request::Request;pub use socket::SocketRequest;pub use tide_disco::http;
Modules
Structs
- Serializable HTTP status code.
- A parsed URL record.
Enums
- HTTP request methods.
Traits
- Errors which can be serialized in a response body.
Functions
- Connect to a server, retrying if the server is not running.
- Build an HTTP
GETrequest. - Build an HTTP
POSTrequest.